Index: trunk/src/org/openstreetmap/josm/actions/JoinAreasAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/JoinAreasAction.java	(revision 11730)
+++ trunk/src/org/openstreetmap/josm/actions/JoinAreasAction.java	(revision 11731)
@@ -939,5 +939,5 @@
             double yRay = y.applyAsDouble(rayFrom);
 
-            for(Way part : parts) {
+            for (Way part : parts) {
                 // intersect against all way segments
                 for (int i = 0; i < part.getNodesCount() - 1; i++) {
Index: trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/StyledMapRenderer.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/StyledMapRenderer.java	(revision 11730)
+++ trunk/src/org/openstreetmap/josm/data/osm/visitor/paint/StyledMapRenderer.java	(revision 11731)
@@ -464,5 +464,5 @@
             Rectangle2D nb = fontMetrics.getStringBounds(name, g); // if slow, approximate by strlen()*maxcharbounds(font)
 
-            Rectangle2D centeredNBounds = text.getLabelPositionSteategy().findLabelPlacement(area, nb);
+            Rectangle2D centeredNBounds = text.getLabelPositionStrategy().findLabelPlacement(area, nb);
             if (centeredNBounds != null) {
                 Font defaultFont = g.getFont();
@@ -751,5 +751,6 @@
      * @since 11670
      */
-    public void drawAreaIcon(OsmPrimitive osm, MapImage img, boolean disabled, boolean selected, boolean member, double theta, PositionForAreaStrategy iconPosition) {
+    public void drawAreaIcon(OsmPrimitive osm, MapImage img, boolean disabled, boolean selected, boolean member, double theta,
+            PositionForAreaStrategy iconPosition) {
         Rectangle2D.Double iconRect = new Rectangle2D.Double(-img.getWidth() / 2.0, -img.getHeight() / 2.0, img.getWidth(), img.getHeight());
 
@@ -1112,5 +1113,5 @@
      */
     public void drawText(OsmPrimitive osm, TextLabel text) {
-        PositionForAreaStrategy position = text.getLabelPositionSteategy();
+        PositionForAreaStrategy position = text.getLabelPositionStrategy();
         if (position.supportsGlyphVector()) {
             if (osm instanceof Way) {
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/AreaIconElement.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/AreaIconElement.java	(revision 11730)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/AreaIconElement.java	(revision 11731)
@@ -14,5 +14,5 @@
  * This class defines how an icon is rendered onto the area.
  * @author Michael Zangl
- * @since 11729
+ * @since 11730
  */
 public class AreaIconElement extends StyleElement {
@@ -32,5 +32,5 @@
     private final PositionForAreaStrategy iconPosition = PositionForAreaStrategy.PARTIALY_INSIDE;
 
-    private AreaIconElement(Cascade c, MapImage iconImage, RotationAngle iconImageAngle) {
+    protected AreaIconElement(Cascade c, MapImage iconImage, RotationAngle iconImageAngle) {
         super(c, 4.8f);
         this.iconImage = Objects.requireNonNull(iconImage, "iconImage");
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/PositionForAreaStrategy.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/PositionForAreaStrategy.java	(revision 11730)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/PositionForAreaStrategy.java	(revision 11731)
@@ -33,5 +33,5 @@
      * @since 11722
      */
-    public static PositionForAreaStrategy forKeyword(Keyword keyword) {
+    static PositionForAreaStrategy forKeyword(Keyword keyword) {
         return forKeyword(keyword, LINE);
     }
@@ -44,5 +44,5 @@
      * @since 11722
      */
-    public static PositionForAreaStrategy forKeyword(Keyword keyword, PositionForAreaStrategy defaultStrategy) {
+    static PositionForAreaStrategy forKeyword(Keyword keyword, PositionForAreaStrategy defaultStrategy) {
         if (keyword == null) {
             return defaultStrategy;
@@ -65,5 +65,5 @@
      * @since 11722
      */
-    public static PositionForAreaStrategy LINE = new OnLineStrategy();
+    PositionForAreaStrategy LINE = new OnLineStrategy();
 
     /**
@@ -72,5 +72,5 @@
      * @since 11722
      */
-    public static PositionForAreaStrategy INSIDE = new CompletelyInsideAreaStrategy();
+    PositionForAreaStrategy INSIDE = new CompletelyInsideAreaStrategy();
 
     /**
@@ -78,5 +78,5 @@
      * @since 11722
      */
-    public static PositionForAreaStrategy PARTIALY_INSIDE = new PartialyInsideAreaStrategy();
+    PositionForAreaStrategy PARTIALY_INSIDE = new PartialyInsideAreaStrategy();
 
     /**
@@ -96,5 +96,5 @@
             return true;
         }
-    };
+    }
 
     /**
@@ -148,7 +148,14 @@
             // |  8  3  7  |
             // +-----------+
-            Rectangle[] candidates = new Rectangle[] { new Rectangle(x2, y1, nbw, nbh), new Rectangle(x3, y2, nbw, nbh),
-                    new Rectangle(x2, y3, nbw, nbh), new Rectangle(x1, y2, nbw, nbh), new Rectangle(x1, y1, nbw, nbh),
-                    new Rectangle(x3, y1, nbw, nbh), new Rectangle(x3, y3, nbw, nbh), new Rectangle(x1, y3, nbw, nbh) };
+            Rectangle[] candidates = new Rectangle[] {
+                    new Rectangle(x2, y1, nbw, nbh),
+                    new Rectangle(x3, y2, nbw, nbh),
+                    new Rectangle(x2, y3, nbw, nbh),
+                    new Rectangle(x1, y2, nbw, nbh),
+                    new Rectangle(x1, y1, nbw, nbh),
+                    new Rectangle(x3, y1, nbw, nbh),
+                    new Rectangle(x3, y3, nbw, nbh),
+                    new Rectangle(x1, y3, nbw, nbh)
+            };
             // Dumb algorithm to find a better placement. We could surely find a smarter one but it should
             // solve most of building issues with only few calculations (8 at most)
@@ -176,5 +183,5 @@
      * @since 11722
      */
-    public class PartialyInsideAreaStrategy extends CompletelyInsideAreaStrategy {
+    class PartialyInsideAreaStrategy extends CompletelyInsideAreaStrategy {
         @Override
         public Rectangle2D findLabelPlacement(Shape area, Rectangle2D nb) {
Index: trunk/src/org/openstreetmap/josm/gui/util/RotationAngle.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/util/RotationAngle.java	(revision 11730)
+++ trunk/src/org/openstreetmap/josm/gui/util/RotationAngle.java	(revision 11731)
@@ -22,5 +22,5 @@
      * The rotation along a way.
      */
-    static final class WayDirectionRotationAngle implements RotationAngle {
+    final class WayDirectionRotationAngle implements RotationAngle {
         @Override
         public double getRotationAngle(OsmPrimitive p) {
@@ -71,5 +71,5 @@
      * A static rotation
      */
-    static final class StaticRotationAngle implements RotationAngle {
+    final class StaticRotationAngle implements RotationAngle {
         private final double angle;
 
@@ -121,5 +121,5 @@
      * @since 11726
      */
-    static RotationAngle NO_ROTATION = new StaticRotationAngle(0);
+    RotationAngle NO_ROTATION = new StaticRotationAngle(0);
 
     /**

Index: trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/TextLabel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/TextLabel.java	(revision 11730)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/styleelement/TextLabel.java	(revision 11731)
@@ -59,5 +59,5 @@
      * The position strategy for this text label.
      */
-    private final PositionForAreaStrategy labelPositionSteategy;
+    private final PositionForAreaStrategy labelPositionStrategy;
 
     /**
@@ -90,7 +90,8 @@
      * @param haloRadius halo radius
      * @param haloColor halo color
-     * @param labelPositionSteategy The position in the area.
-     */
-    protected TextLabel(LabelCompositionStrategy strategy, Font font, int xOffset, int yOffset, Color color, Float haloRadius, Color haloColor, PositionForAreaStrategy labelPositionSteategy) {
+     * @param labelPositionStrategy The position in the area.
+     */
+    protected TextLabel(LabelCompositionStrategy strategy, Font font, int xOffset, int yOffset, Color color, Float haloRadius,
+            Color haloColor, PositionForAreaStrategy labelPositionStrategy) {
         this.labelCompositionStrategy = strategy;
         this.font = Objects.requireNonNull(font, "font");
@@ -100,5 +101,5 @@
         this.haloRadius = haloRadius;
         this.haloColor = haloColor;
-        this.labelPositionSteategy = Objects.requireNonNull(labelPositionSteategy, "labelPositionSteategy");
+        this.labelPositionStrategy = Objects.requireNonNull(labelPositionStrategy, "labelPositionStrategy");
     }
 
@@ -116,5 +117,5 @@
         this.haloColor = other.haloColor;
         this.haloRadius = other.haloRadius;
-        this.labelPositionSteategy = other.labelPositionSteategy;
+        this.labelPositionStrategy = other.labelPositionStrategy;
     }
 
@@ -123,7 +124,7 @@
      *
      * @param other the other element.
-     * @param labelPositionSteategy the position
-     */
-    private TextLabel(TextLabel other, PositionForAreaStrategy labelPositionSteategy) {
+     * @param labelPositionStrategy the position
+     */
+    private TextLabel(TextLabel other, PositionForAreaStrategy labelPositionStrategy) {
         this.labelCompositionStrategy = other.labelCompositionStrategy;
         this.font = other.font;
@@ -133,5 +134,5 @@
         this.haloColor = other.haloColor;
         this.haloRadius = other.haloRadius;
-        this.labelPositionSteategy = labelPositionSteategy;
+        this.labelPositionStrategy = labelPositionStrategy;
     }
 
@@ -242,10 +243,10 @@
      * @since 11722
      */
-    public PositionForAreaStrategy getLabelPositionSteategy() {
-        return labelPositionSteategy;
-    }
-
-    public TextLabel withPosition(PositionForAreaStrategy labelPositionSteategy) {
-        return new TextLabel(this, labelPositionSteategy);
+    public PositionForAreaStrategy getLabelPositionStrategy() {
+        return labelPositionStrategy;
+    }
+
+    public TextLabel withPosition(PositionForAreaStrategy labelPositionStrategy) {
+        return new TextLabel(this, labelPositionStrategy);
     }
 